@@ -165,7 +165,7 @@ int check_dir (char *dir, char *path, int linkcount, int norecurse)
 
   numdirs = 0;
   dl = (struct dirinfolist *)NULL;
-  while (finfo = readdir(dirhandle)) {
+  while ((finfo = readdir(dirhandle))) {
     if (!strcmp(finfo->d_name, ".") || !strcmp(finfo->d_name, ".."))
       continue;
 
