@@ -1,6 +1,6 @@
 /*
-  (C) Nelson Murilo - 2003/06/07
-  Version 0.8
+  (C) Nelson Murilo - 2004/09/13
+  Version 0.9
   C port from chkproc.pl code from Klaus Steding-Jessen <jessen@nic.br>
   and Cristine Hoepers <cristine@nic.br> +little output changes.
 
@@ -33,6 +33,8 @@
 
   2004/04/03 - More fix for linux's threads - Nelson Murilo
 
+  2004/09/13 - More and more fix for linux's threads - Nelson Murilo
+
 */
 
 #if !defined(__linux__) && !defined(__FreeBSD__) && !defined(__sun)
@@ -66,7 +68,7 @@ int main (){ return 0; }
 
 static char *ps_cmds[] = {
 	    "ps -edf",
-	    "ps auxw",
+	    "ps mauxw",
             "ps auxw -T|tr -s ' '|cut -d' ' -f2-",
           };
 
